Interface AccessTokenIssueEventListener

All Superinterfaces:
EventListener, Lifecycle

@ThreadSafe public interface AccessTokenIssueEventListener extends Lifecycle, EventListener
Service Provider Interface (SPI) for listening to access token issue events.

Implementations must be thread-safe. Listeners that emit events should use a separate thread for blocking operations.

  • Method Details

    • accessTokenIssued

      This method is called when an access token is issued.
      Parameters:
      event - The access token issue event. Not null.
      eventContext - Provides access to additional parameters about the event as well as helpers for its processing. Not null.