Interface TokenResponseContext
- All Superinterfaces:
InvocationContext
The token response context.
-
Method Summary
Modifier and TypeMethodDescription@Nullable net.minidev.json.JSONObjectFor a successful token response returns the optional authorisation data.Returns the claim names compressor.Returns the OpenID claims source.Returns an interface for signing JSON Web Tokens (JWT).@Nullable com.nimbusds.openid.connect.sdk.rp.OIDCClientInformationIf the requesting client is successfully authenticated or identified at the token endpoint returns its registered information.Methods inherited from interface com.nimbusds.openid.connect.provider.spi.InvocationContext
getIssuer
-
Method Details
-
getOIDCClientInformation
@Nullable com.nimbusds.openid.connect.sdk.rp.OIDCClientInformation getOIDCClientInformation()If the requesting client is successfully authenticated or identified at the token endpoint returns its registered information.- Returns:
- The client information,
nullif not available.
-
getAuthorizationData
@Nullable net.minidev.json.JSONObject getAuthorizationData()For a successful token response returns the optional authorisation data.- Returns:
- The authorisation data,
nullif not specified.
-
getCommonClaimsSource
Returns the OpenID claims source.- Returns:
- The OpenID claims source. Not
null.
-
getClaimNamesCompressor
Returns the claim names compressor. Intended to reduce the size of the consented claims array in self-contained (JWT-encoded) access tokens.- Returns:
- The claim names compressor.
-
getJWTSigner
Returns an interface for signing JSON Web Tokens (JWT).- Returns:
- The JWT signer.
-