Interface AccessTokenIssueEventListener
- All Superinterfaces:
EventListener,Lifecycle
Service Provider Interface (SPI) for listening to access token issue events.
Implementations must be thread-safe. Listeners that emit events should use a separate thread for blocking operations.
-
Method Summary
Modifier and TypeMethodDescriptionvoidaccessTokenIssued(AccessTokenIssueEvent event, EventContext eventContext) This method is called when an access token is issued.
-
Method Details
-
accessTokenIssued
This method is called when an access token is issued.- Parameters:
event- The access token issue event. Notnull.eventContext- Provides access to additional parameters about the event as well as helpers for its processing. Notnull.
-