Interface SubjectAuthAndConsentEventListener
- All Superinterfaces:
EventListener,Lifecycle
Service Provider Interface (SPI) for listening to subject authentication and
consent events.
Implementations must be thread-safe. Listeners that emit events should use a separate thread for blocking operations.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsubjectAuthenticatedAndConsented(SubjectAuthAndConsentEvent event, EventContext eventContext) This method is called when a subject is authenticated and consents.
-
Method Details
-
subjectAuthenticatedAndConsented
This method is called when a subject is authenticated and consents.For clients using the code flow (
response_type=code), the event is dispatched when the client submits a valid authorisation code at the token endpoint of the Connect2id server.For clients using an implicit (
response_type=token,response_type=id_token,id_token token) or hybrid flow (response_type=code id_token,response_type=code token,response_type=code id_token token, the event is dispatched when the request at the authorisation endpoint of the Connect2id server successfully completes.- Parameters:
event- The subject authentication and consented event.eventContext- Provides access to additional parameters about the event as well as helpers for its processing. Notnull.
-